src/hotspot/share/services/lowMemoryDetector.hpp
changeset 58503 726a3945e934
parent 53244 9807daeb47c4
child 59290 97d13893ec3c
--- a/src/hotspot/share/services/lowMemoryDetector.hpp	Tue Oct 08 15:03:20 2019 +0100
+++ b/src/hotspot/share/services/lowMemoryDetector.hpp	Tue Oct 08 09:13:08 2019 -0700
@@ -59,7 +59,8 @@
 //
 // May need to deal with hysteresis effect.
 //
 // Memory detection code runs in the Service thread (serviceThread.hpp).
 
 class OopClosure;
 class MemoryPool;
@@ -214,6 +215,7 @@
 class LowMemoryDetector : public AllStatic {
   friend class LowMemoryDetectorDisabler;
   friend class ServiceThread;
+  friend class NotificationThread;
 private:
   // true if any collected heap has low memory detection enabled
   static volatile bool _enabled_for_collected_pools;
@@ -59,7 +59,8 @@
 // May need to deal with hysteresis effect.
 //
-// Memory detection code runs in the Service thread (serviceThread.hpp).
+// Memory detection code runs in the Notification thread or
+// ServiceThread depending on UseNotificationThread flag.
 
 class OopClosure;